@@ -203,3 +203,87 @@ void CleaN900::on_actionHardware_Details_triggered()
     process.start("sh harddet.sh");
     process.waitForFinished();
 }
+
+void CleaN900::on_actionDonate_triggered()
+{
+    QProcess process;
+    process.start("sh donate.sh");
+    process.waitForFinished();
+}
+
+void CleaN900::on_searchhome_clicked()
+{
+    QProcess process;
+    process.start("sh searchall.sh");
+    process.waitForFinished();
+}
+
+void CleaN900::on_searchMy_clicked()
+{
+    QProcess process;
+    process.start("sh searchMyDocs.sh");
+    process.waitForFinished();
+}
+
+void CleaN900::on_search_clicked()
+{
+    QProcess process;
+    process.start("sh searchspe.sh");
+    process.waitForFinished();
+}
+
+void CleaN900::on_pushButton_clicked()
+{
+    QProcess process;
+    process.start("sh dicell.sh");
+    process.waitForFinished();
+}
+
+void CleaN900::on_difm_clicked()
+{
+    QProcess process;
+    process.start("sh difm.sh");
+    process.waitForFinished();
+}
+
+void CleaN900::on_diblue_clicked()
+{
+    QProcess process;
+    process.start("sh diblue.sh");
+    process.waitForFinished();
+}
+
+void CleaN900::on_encell_clicked()
+{
+    QProcess process;
+    process.start("sh encell.sh");
+    process.waitForFinished();
+}
+
+void CleaN900::on_enfm_clicked()
+{
+    QProcess process;
+    process.start("sh enfm.sh");
+    process.waitForFinished();
+}
+
+void CleaN900::on_enblue_clicked()
+{
+    QProcess process;
+    process.start("sh enblue.sh");
+    process.waitForFinished();
+}
+
+void CleaN900::on_general_clicked()
+{
+    QProcess process;
+    process.start("sh engen.sh");
+    process.waitForFinished();
+}
+
+void CleaN900::on_silent_clicked()
+{
+    QProcess process;
+    process.start("sh ensile.sh");
+    process.waitForFinished();
+}
