@@ -19,6 +19,18 @@ private:
     Ui::CleaN900 *ui;
 
 private slots:
+    void on_silent_clicked();
+    void on_general_clicked();
+    void on_enblue_clicked();
+    void on_enfm_clicked();
+    void on_encell_clicked();
+    void on_diblue_clicked();
+    void on_difm_clicked();
+    void on_pushButton_clicked();
+    void on_search_clicked();
+    void on_searchMy_clicked();
+    void on_searchhome_clicked();
+    void on_actionDonate_triggered();
     void on_actionHardware_Details_triggered();
     void on_pushDpkgPurge_clicked();
     void on_pushDet_clicked();
